import org.apache.commons.lang3.StringUtils

insight = new InsightTool(logger: logger, insightAccessToken: insightAccessToken, insightUserEmail: insightUserEmail, insightApiToken: insightApiToken, apiClientFactory: apiClientFactory)

/**
 * Velocity tool to get Insight object data from the Insight in Jira Service Management REST API
 * or from the Insight Cloud REST API.
 */
class InsightTool {
	def logger

	/* Insight authentication parameters. */
	def insightAccessToken // FIXME remove when Insight Legacy is terminated (31 Mar 2022)
	def insightUserEmail
	def insightApiToken

	def apiClientFactory

	def insightClient // FIXME remove when Insight Legacy is terminated (31 Mar 2022)
	def insightInJiraServiceManagementClient

	/**
	 * Returns the Insight Asset Management objects (legacy app) for the passed custom field value (as Groovy objects)
	 * or the exception object if something went wrong.
	 */
	def getInsightObjects(def customFieldValue) { // FIXME remove when Insight Legacy is terminated (31 Mar 2022)
		try {
			if (!insightClient) {
				insightClient = apiClientFactory.createInsightClient(insightAccessToken)
			}
			def insightObjectIds = customFieldValue.collect { StringUtils.substringAfterLast(it.originId, "_") }
			return insightClient.getInsightObjects(insightObjectIds)
		} catch (Throwable ex) {
			return ex
		}
	}

	/**
	 * Returns the Insight in Jira Service Management objects for the passed custom field value (as Groovy objects)
	 * or the exception object if something went wrong.
	 */
	def getInsightInJiraServiceManagementObjects(def customFieldValue) {
		try {
			if (!insightInJiraServiceManagementClient) {
				def workspaceId = customFieldValue[0].workspaceId
				insightInJiraServiceManagementClient = apiClientFactory.createInsightInJiraServiceManagementClient(workspaceId, insightUserEmail, insightApiToken)
			}
			def insightObjectIds = customFieldValue.collect { it.objectId }
			return insightInJiraServiceManagementClient.getInsightObjects(insightObjectIds)
		} catch (Throwable ex) {
			return ex
		}
	}
}
